==> crm-commom-vo-1.2.2.35.release.jar: com/biz/crm/nebular/mdm/position/resp/MdmPositionPageRespVo.java <==
package com.biz.crm.nebular.mdm.position.resp;

import com.biz.crm.config.CrmColumnResolve;
import com.biz.crm.config.CrmDict;
import com.biz.crm.nebular.mdm.CrmTreeTenVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 职位管理列表返回VO
 *
 * @author Tao.Chen
 * @date 2020-11-17 20:23:13
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "职位管理列表返回VO")
@CrmColumnResolve
public class MdmPositionPageRespVo extends CrmTreeTenVo {

    @ApiModelProperty("职位编码")
    private String positionCode;

    @ApiModelProperty("职位名称")
    private String positionName;

    @ApiModelProperty("关联组织编码")
    private String orgCode;

    @ApiModelProperty("组织名称")
    private String orgName;

    @ApiModelProperty("职位级别编码")
    private String positionLevelCode;

    @ApiModelProperty("职位级别名称")
    private String positionLevelName;

    @ApiModelProperty("是否主职位1是0否")
    private String primaryFlag;

    @ApiModelProperty("是否主职位1是0否名称")
    @CrmDict(typeCode = "primary_flag",dictCodeField = "primaryFlag")
    private String primaryFlagName;

    @ApiModelProperty("用户登录名")
    private String userName;

    @ApiModelProperty("用户姓名")
    private String fullName;

    @ApiModelProperty("用户编码")
    private String userCode;

    @ApiModelProperty("上级职位编码")
    private String parentCode;

    @ApiModelProperty("上级职位名称")
    private String parentName;

    @ApiModelProperty("上级用户编码")
    private String parentUserName;

    @ApiModelProperty("上级用户名称")
    private String parentFullName;

    @ApiModelProperty("上级用户编码")
    private String parentUserCode;

    @ApiModelProperty("上级组织编码")
    private String parentOrgCode;

    @ApiModelProperty("上级组织名称")
    private String parentOrgName;

    @ApiModelProperty("角色编码，多个用英文逗号隔开")
    private String roleCode;

    @ApiModelProperty("角色名称，多个用英文逗号隔开")
    private String roleName;

    @ApiModelProperty("职位冗余全部关联角色编码集合，英文逗号间隔")
    private String roleCodeRedundancy;

    @ApiModelProperty("职位冗余全部关联角色名称集合，英文逗号间隔")
    private String roleNameRedundancy;

}

==> crm-commom-vo-1.2.4.release.jar: com/biz/crm/nebular/mdm/position/resp/MdmPositionPageRespVo.java <==
package com.biz.crm.nebular.mdm.position.resp;

import com.biz.crm.config.CrmColumnResolve;
import com.biz.crm.config.CrmDict;
import com.biz.crm.nebular.mdm.CrmTreeTenVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 职位管理列表返回VO
 *
 * @author Tao.Chen
 * @date 2020-11-17 20:23:13
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "职位管理列表返回VO")
@CrmColumnResolve
public class MdmPositionPageRespVo extends CrmTreeTenVo {

    @ApiModelProperty("职位编码")
    private String positionCode;

    @ApiModelProperty("职位名称")
    private String positionName;

    @ApiModelProperty("关联组织编码")
    private String orgCode;

    @ApiModelProperty("组织名称")
    private String orgName;

    @ApiModelProperty("职位级别编码")
    private String positionLevelCode;

    @ApiModelProperty("职位级别名称")
    private String positionLevelName;

    @ApiModelProperty("是否主职位1是0否")
    private String primaryFlag;

    @ApiModelProperty("是否主职位1是0否名称")
    @CrmDict(typeCode = "primary_flag",dictCodeField = "primaryFlag")
    private String primaryFlagName;

    @ApiModelProperty("用户登录名")
    private String userName;

    @ApiModelProperty("用户姓名")
    private String fullName;

    @ApiModelProperty("用户编码")
    private String userCode;

    @ApiModelProperty("上级职位编码")
    private String parentCode;

    @ApiModelProperty("上级职位名称")
    private String parentName;

    @ApiModelProperty("上级用户编码")
    private String parentUserName;

    @ApiModelProperty("上级用户名称")
    private String parentFullName;

    @ApiModelProperty("上级用户编码")
    private String parentUserCode;

    @ApiModelProperty("上级组织编码")
    private String parentOrgCode;

    @ApiModelProperty("上级组织名称")
    private String parentOrgName;

    @ApiModelProperty("角色编码，多个用英文逗号隔开")
    private String roleCode;

    @ApiModelProperty("角色名称，多个用英文逗号隔开")
    private String roleName;

    @Deprecated
    private String roleCodeRedundancy;

    @Deprecated
    private String roleNameRedundancy;

}
